@@ -1,11 +1,12 @@
 """Basic statistics protocol."""
 
-from ipaddress import IPv4Address, IPv6Address
-from typing import NamedTuple, Union
+from __future__ import annotations
+from typing import NamedTuple
 
 from mcipc.query.proto.common import MAGIC
 from mcipc.query.proto.common import random_session_id
 from mcipc.query.proto.common import ip_or_hostname
+from mcipc.query.proto.common import IPAddressOrHostname
 from mcipc.query.proto.common import Type
 
 
@@ -29,7 +30,7 @@ class Request(NamedTuple):
         return payload
 
     @classmethod
-    def create(cls, challenge_token, session_id=None):
+    def create(cls, challenge_token: int, session_id: int = None) -> Request:
         """Creates a new request with the specified challenge
         token and the specified or a random session ID.
         """
@@ -50,27 +51,17 @@ class BasicStats(NamedTuple):
     num_players: int
     max_players: int
     host_port: int
-    host_ip: Union[IPv4Address, IPv6Address, str]
+    host_ip: IPAddressOrHostname
 
     @classmethod
-    def from_bytes(cls, bytes_):    # pylint: disable=R0914
+    def from_bytes(cls, bytes_: bytes) -> BasicStats:   # pylint: disable=R0914
         """Creates the packet from the respective bytes."""
         type_ = Type.from_bytes(bytes_[0:1])
         session_id = int.from_bytes(bytes_[1:5], 'big', signed=True)
-
-        try:
-            motd, *blocks, port_ip, _ = bytes_[5:].split(b'\0')
-        except ValueError:
-            raise ValueError('Unexpected amount of Null terminated strings.')
-
+        motd, *blocks, port_ip, _ = bytes_[5:].split(b'\0')
         motd = motd.decode('latin-1')
         strings = [block.decode('latin-1') for block in blocks]
-
-        try:
-            game_type, map_, num_players, max_players = strings
-        except ValueError:
-            raise ValueError('Unexpected amount of string fields.')
-
+        game_type, map_, num_players, max_players = strings
         num_players = int(num_players)
         max_players = int(max_players)
         host_port = int.from_bytes(port_ip[0:2], 'little')
@@ -79,7 +70,7 @@ class BasicStats(NamedTuple):
             type_, session_id, motd, game_type, map_, num_players, max_players,
             host_port, host_ip)
 
-    def to_json(self, ip_type=str) -> dict:
+    def to_json(self) -> dict:
         """Returns a JSON-ish dict."""
         return {
             'type': self.type.value,
@@ -90,7 +81,7 @@ class BasicStats(NamedTuple):
             'num_players': self.num_players,
             'max_players': self.max_players,
             'host_port': self.host_port,
-            'host_ip': ip_type(self.host_ip)
+            'host_ip': str(self.host_ip)
         }
 
 
