@@ -1,15 +1,24 @@
 """Common protocol stuff."""
 
+from __future__ import annotations
 from enum import Enum
 from ipaddress import ip_address, IPv4Address, IPv6Address
 from random import randint
+from typing import Union
 
 
-__all__ = ['MAGIC', 'random_session_id', 'ip_or_hostname', 'Type']
+__all__ = [
+    'MAGIC',
+    'random_session_id',
+    'ip_or_hostname',
+    'IPAddressOrHostname',
+    'Type'
+]
 
 
 MAGIC = b'\xfe\xfd'
 SESSION_ID_MASK = 0x0F0F0F0F
+IPAddressOrHostname = Union[IPv4Address, IPv6Address, str]
 
 
 def random_session_id() -> int:
@@ -20,7 +29,7 @@ def random_session_id() -> int:
     return randint(-2147483648, 2147483647 + 1) & SESSION_ID_MASK
 
 
-def ip_or_hostname(string) -> IPv4Address or IPv6Address or str:
+def ip_or_hostname(string: str) -> IPAddressOrHostname:
     """Returns an IPv4 or IPv6 address if applicable, else a string."""
 
     try:
@@ -40,6 +49,6 @@ class Type(Enum):
         return self.value.to_bytes(1, 'big')    # pylint: disable=E1101
 
     @classmethod
-    def from_bytes(cls, bytes_):
+    def from_bytes(cls, bytes_: bytes) -> Type:
         """Returns the type from the respective bytes."""
         return cls(int.from_bytes(bytes_, 'big'))
